==> dif-content-manager-db-2.2.15-3-20171025.104047-1-sources.jar: pt/digitalis/dif/content/model/ContentManagerFactory.java <==
package pt.digitalis.dif.content.model;

import org.hibernate.Session;
import org.hibernate.cfg.Configuration;

import pt.digitalis.dif.model.hibernate.HibernateUtil;

/**
 * NOTE: This file is auto generated and will be overwritten in a future file generation.
 */
public class ContentManagerFactory {

	/** The session factory name. */
    public static String SESSION_FACTORY_NAME = "ContentManager";

    /**
     * Obtains the current session Configuration
     * 
     * @return the Configuration object
     */
    static public Configuration getConfiguration()
    {
        return HibernateUtil.getDatabaseConfiguration(SESSION_FACTORY_NAME, null);
    }

	/**
	 * Obtains the current session
	 *
	 * @return the session object
	 */
    static public Session getSession() 
    {
    	return HibernateUtil.getSessionFactory(SESSION_FACTORY_NAME).getCurrentSession();
    }
    
    /**
     * Sets the session factory name.
     * 
     * @param name
     *            the new session factory name
     */
    public static void setSessionFactoryName(String name)
    {
        SESSION_FACTORY_NAME = name;
    }
    
   /**
     * Open transaction. Checks if there are a transaction is active
     *
     * @return true, if the there was a already active transaction
     */
    public static boolean openTransaction()
    {
        boolean wasActive = ContentManagerFactory.getSession().getTransaction().isActive();

        if (!wasActive)
        {
            ContentManagerFactory.getSession().beginTransaction();
        }
        return wasActive;
    }
}

==> dif-content-manager-db-2.3.5-3-sources.jar: pt/digitalis/dif/content/model/ContentManagerFactory.java <==
package pt.digitalis.dif.content.model;

import org.hibernate.LobHelper;
import org.hibernate.Session;
import org.hibernate.cfg.Configuration;

import pt.digitalis.dif.model.hibernate.HibernateUtil;

/**
 * NOTE: This file is auto generated and will be overwritten in a future file generation.
 */
public class ContentManagerFactory {

	/** The session factory name. */
    public static String SESSION_FACTORY_NAME = "ContentManager";

    /**
     * Obtains the current session Configuration
     * 
     * @return the Configuration object
     */
    static public Configuration getConfiguration()
    {
        return HibernateUtil.getDatabaseConfiguration(SESSION_FACTORY_NAME, null);
    }

    /**
     * Gets the lob helper.
     *
     * @return the lob helper
     */
    public static LobHelper getLobHelper()
    {
        boolean wasActive = openTransaction();

        LobHelper result = ContentManagerFactory.getSession().getLobHelper();

        if (!wasActive)
        {
            ContentManagerFactory.getSession().getTransaction().commit();
        }

        return result;
    }

	/**
	 * Obtains the current session
	 *
	 * @return the session object
	 */
    static public Session getSession() 
    {
    	return HibernateUtil.getSessionFactory(SESSION_FACTORY_NAME).getCurrentSession();
    }
    
    /**
     * Sets the session factory name.
     * 
     * @param name
     *            the new session factory name
     */
    public static void setSessionFactoryName(String name)
    {
        SESSION_FACTORY_NAME = name;
    }
    
   /**
     * Open transaction. Checks if there are a transaction is active
     *
     * @return true, if the there was a already active transaction
     */
    public static boolean openTransaction()
    {
        boolean wasActive = ContentManagerFactory.getSession().getTransaction().isActive();

        if (!wasActive)
        {
            ContentManagerFactory.getSession().beginTransaction();
        }
        return wasActive;
    }
}
